@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.34 2002/02/21 05:17:25 hadess Exp $ */
+/* $Id: gdict-app.c,v 1.39 2002/04/15 11:53:55 kmaraas Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -49,6 +49,7 @@ GDictDefbox *defbox;
 GDictSpeller *speller;
 GtkWidget *pref_dialog;
 GtkWidget *socket_error_dialog;
+gboolean  gail_loaded = FALSE;
 
 #ifdef HAVE_GNOME_PRINT
 GnomePrinter *gdict_printer = NULL;
@@ -136,13 +137,6 @@ spell_not_found_cb (GtkWidget *widget, gpointer data)
     gnome_appbar_refresh (GNOME_APPBAR (gdict_appbar));
 }
 
-static gint
-spell_close_cb (GtkWidget *widget, gpointer data) 
-{
-    speller = NULL;
-    return FALSE;
-}
-
 void
 gdict_open_speller (void) 
 {
@@ -159,8 +153,6 @@ gdict_open_speller (void)
                             GTK_SIGNAL_FUNC (spell_not_found_cb), NULL);
         gtk_signal_connect (GTK_OBJECT (speller), "socket_error",
                             GTK_SIGNAL_FUNC (socket_error_cb), NULL);
-        gtk_signal_connect (GTK_OBJECT (speller), "close",
-                            GTK_SIGNAL_FUNC (spell_close_cb), NULL);
         gtk_widget_show_all (GTK_WIDGET (speller));
     }
     else
@@ -482,6 +474,63 @@ about_cb (GtkMenuItem *menuitem, gpointer user_data)
     gdict_about();
 }
 
+
+/*
+ * add_atk_namedesc
+ * @widget    : The Gtk Widget for which @name and @desc are added.
+ * @name      : Accessible Name
+ * @desc      : Accessible Description
+ * Description: This function adds accessible name and description to a
+ *              Gtk widget.
+ */
+
+void
+add_atk_namedesc(GtkWidget *widget, const gchar *name, const gchar *desc)
+{
+    AtkObject *atk_widget;
+
+    g_return_if_fail (GTK_IS_WIDGET(widget));
+
+    atk_widget = gtk_widget_get_accessible(widget);
+    
+    if( name != NULL )
+    atk_object_set_name(atk_widget, name);
+    if( desc !=NULL )
+    atk_object_set_description(atk_widget, desc);
+}
+
+
+/*
+ * add_atk_relation
+ * @obj1      : The first widget in the relation @rel_type
+ * @obj2      : The second widget in the relation @rel_type.
+ * @rel_type  : Relation type which relates @obj1 and @obj2
+ * Description: This function establishes Atk Relation between two given
+ *              objects.
+ */
+
+void
+add_atk_relation(GtkWidget *obj1, GtkWidget *obj2, AtkRelationType rel_type)
+{
+
+    AtkObject *atk_obj1, *atk_obj2;
+    AtkRelationSet *relation_set;
+    AtkRelation *relation;
+
+    g_return_if_fail (GTK_IS_WIDGET(obj1));
+    g_return_if_fail (GTK_IS_WIDGET(obj2));
+
+    atk_obj1 = gtk_widget_get_accessible(obj1);
+
+    atk_obj2 = gtk_widget_get_accessible(obj2);
+
+    relation_set = atk_object_ref_relation_set (atk_obj1);
+    relation = atk_relation_new(&atk_obj2, 1, rel_type);
+    atk_relation_set_add(relation_set, relation);
+    g_object_unref(G_OBJECT (relation));
+
+}
+
 static GnomeUIInfo file_menu_uiinfo[] = {
     GNOMEUIINFO_ITEM_STOCK (N_("Lookup"),
 			    N_("Lookup word in dictionary"),
@@ -517,14 +566,13 @@ static GnomeUIInfo edit_menu_uiinfo[] = {
     GNOMEUIINFO_SEPARATOR,
     GNOMEUIINFO_MENU_FIND_ITEM (find_cb, NULL),
     GNOMEUIINFO_MENU_FIND_AGAIN_ITEM (find_again_cb, NULL),
-    GNOMEUIINFO_END
-};
-
-static GnomeUIInfo settings_menu_uiinfo[] = {
+    GNOMEUIINFO_SEPARATOR,
     GNOMEUIINFO_MENU_PREFERENCES_ITEM (preferences_cb, NULL),
     GNOMEUIINFO_END
 };
 
+
+
 static GnomeUIInfo help_menu_uiinfo[] = {
     GNOMEUIINFO_HELP(APPNAME),
     GNOMEUIINFO_MENU_ABOUT_ITEM (about_cb, NULL),
@@ -534,7 +582,6 @@ static GnomeUIInfo help_menu_uiinfo[] = {
 static GnomeUIInfo menubar_uiinfo[] = {
     GNOMEUIINFO_MENU_FILE_TREE (file_menu_uiinfo),
     GNOMEUIINFO_MENU_EDIT_TREE (edit_menu_uiinfo),
-    GNOMEUIINFO_MENU_SETTINGS_TREE (settings_menu_uiinfo),
     GNOMEUIINFO_MENU_HELP_TREE (help_menu_uiinfo),
     GNOMEUIINFO_END
 };
@@ -553,7 +600,7 @@ GtkWidget *gdict_app_create (gboolean applet) {
     GtkWidget *vbox;
     GtkWidget *hbox;
     GtkWidget *button;
-    GtkWidget *label;
+    GtkWidget *label, *word_label;
     GtkWidget *scrolled;
     GtkWidget *defbox_vscrollbar;
     GtkTooltips *tooltips;
@@ -567,7 +614,7 @@ GtkWidget *gdict_app_create (gboolean applet) {
   
     tooltips = gtk_tooltips_new ();
   
-    gdict_app = gnome_app_new ("Dictionary", "Dictionary");
+    gdict_app = gnome_app_new ("gnome-dictionary", _("Dictionary"));
     gtk_window_set_default_size (GTK_WINDOW (gdict_app), 450, 330);
     
     dock = GNOME_APP (gdict_app)->dock;
@@ -588,9 +635,9 @@ GtkWidget *gdict_app_create (gboolean applet) {
     gtk_widget_show (hbox);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     
-    label = gtk_label_new (_("Word : "));
-    gtk_widget_show (label);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    word_label = gtk_label_new_with_mnemonic (_("_Word : "));
+    gtk_widget_show ( GTK_WIDGET(word_label) );
+    gtk_box_pack_start (GTK_BOX (hbox), word_label, FALSE, FALSE, 0);
     
     label = gtk_label_new_with_mnemonic (_("_Look Up"));
     gtk_widget_show (label);
@@ -610,11 +657,22 @@ GtkWidget *gdict_app_create (gboolean applet) {
     gnome_word_entry = gnome_entry_new ("Wordentry");
     gtk_widget_show (gnome_word_entry);
     gtk_box_pack_start (GTK_BOX (hbox), gnome_word_entry, TRUE, TRUE, 0);
-    GTK_WIDGET_SET_FLAGS (gnome_word_entry, GTK_CAN_FOCUS);
-    gtk_widget_grab_focus (gnome_word_entry);
     gnome_entry_set_max_saved (GNOME_ENTRY (gnome_word_entry), 50);
     word_entry = gnome_entry_gtk_entry(GNOME_ENTRY (gnome_word_entry));
-        
+   
+    gtk_label_set_mnemonic_widget (GTK_LABEL (word_label), word_entry);
+    GTK_WIDGET_SET_FLAGS (word_entry, GTK_CAN_FOCUS);
+    gtk_widget_grab_focus (word_entry);
+
+    if ( GTK_IS_ACCESSIBLE (gtk_widget_get_accessible(gnome_word_entry)))
+    {
+        gail_loaded = TRUE;
+        add_atk_namedesc(GTK_WIDGET(word_label), _("Word"), _("Word"));
+        add_atk_namedesc(gnome_word_entry, _("Word Entry"), _("Enter a Word or select one from the list below"));
+        add_atk_relation(gnome_word_entry, GTK_WIDGET(word_label), ATK_RELATION_LABELLED_BY);
+        add_atk_namedesc(GTK_WIDGET(button), NULL, _("Look Up for a Word"));
+    }
+
     scrolled = gtk_scrolled_window_new (NULL, NULL);
     gtk_container_set_border_width (GTK_CONTAINER (scrolled), GNOME_PAD_SMALL);    
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
