@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.28 2002/02/17 15:10:05 kevinv Exp $ */
+/* $Id: gdict-applet.c,v 1.30 2002/02/25 04:06:18 hadess Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -130,17 +130,19 @@ text_received (GtkClipboard *clipboard, const gchar *text, gpointer data)
 	if (!GTK_WIDGET_VISIBLE (gdict_app))
         	gtk_widget_show (gdict_app);
         	
-        gtk_window_present (GTK_WINDOW (gdict_app));
-        
-    	if (!text)
-    		return;
-    	
-    	lookup_text = g_strdup (text);	
+	gtk_window_present (GTK_WINDOW (gdict_app));
+
+	if (!text)
+		return;
+
+	lookup_text = g_strstrip (text);
+#if 0
 	g_print ("text = %s \n", lookup_text);
-			
+#endif
+
 	if (!context)
 		gdict_init_context ();
-    	
+
     	if (*lookup_text == 0)
         	return;
     	g_strdown (lookup_text);
