@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.22 2002/03/21 03:33:47 kevinv Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.23 2002/04/04 03:38:26 kevinv Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -79,8 +79,10 @@ static void pref_dialog_ok_cb       (GtkWidget *widget, gpointer data);
 static void pref_dialog_apply_cb    (GtkWidget *widget, gpointer data);
 static void pref_dialog_close_cb    (GtkWidget *widget, gpointer data);
 static void response_cb		    (GtkDialog *dialog, gint response);
-static void server_button_cb	    (GtkButton *button, gpointer data);
-static void port_button_cb	    (GtkButton *button, gpointer data);
+static gboolean	set_server_cb 	    (GtkWidget *widget, GdkEventFocus *event, gpointer data);
+static gboolean set_port_cb	    (GtkWidget *widget, GdkEventFocus *event, gpointer data);
+static void set_default_server      (GtkButton *button, gpointer data);
+static void set_default_port        (GtkButton *button, gpointer data);
 static void smart_lookup_cb	    (GtkToggleButton *toggle, gpointer data);
 
 /* gdict_pref_dialog_get_type
@@ -197,38 +199,46 @@ create_dialog (GDictPrefDialog *pref_dialog)
     gtk_table_attach_defaults (pref_dialog->table, 
                                GTK_WIDGET (pref_dialog->server_entry), 
                                1, 2, 0, 1);
+    g_signal_connect (G_OBJECT (pref_dialog->server_entry), "focus_out_event",
+    		      G_CALLBACK (set_server_cb), pref_dialog);
     
-    server_label = gtk_label_new (_("Server:"));
+    server_label = gtk_label_new_with_mnemonic (_("_Server:"));
+    gtk_label_set_mnemonic_widget (GTK_LABEL (server_label), 
+    				   GTK_WIDGET (pref_dialog->server_entry));
     gtk_label_set_justify (GTK_LABEL (server_label), GTK_JUSTIFY_RIGHT);
     gtk_misc_set_alignment (GTK_MISC (server_label), 1, 0.5);
     gtk_table_attach_defaults (pref_dialog->table, server_label, 0, 1, 0, 1);
     
-    button = gtk_button_new_with_mnemonic (_("Set _Server"));
+    button = gtk_button_new_with_mnemonic (_("De_fault"));
     gtk_table_attach_defaults (pref_dialog->table, button, 2, 3, 0, 1);
     g_signal_connect (G_OBJECT (button), "clicked",
-    		      G_CALLBACK (server_button_cb), pref_dialog);
+    		      G_CALLBACK (set_default_server), pref_dialog);
 
     if( gail_loaded )
-        add_atk_namedesc(GTK_WIDGET(button), NULL, _("Set the dictionary server"));
+        add_atk_namedesc(GTK_WIDGET(button), NULL, _("Reset server to default"));
 
-    port_label = gtk_label_new (_("Port:"));
+    port_label = gtk_label_new_with_mnemonic (_("_Port:"));
     gtk_table_attach_defaults (pref_dialog->table, port_label, 0, 1, 1, 2);
     gtk_label_set_justify (GTK_LABEL (port_label), GTK_JUSTIFY_RIGHT);
     gtk_misc_set_alignment (GTK_MISC (port_label), 1, 0.5);
 
     pref_dialog->port_entry = GTK_ENTRY (gtk_entry_new ());
+    gtk_label_set_mnemonic_widget (GTK_LABEL (port_label), 
+    				   GTK_WIDGET (pref_dialog->port_entry));
     gtk_table_attach_defaults (pref_dialog->table, 
                                GTK_WIDGET (pref_dialog->port_entry), 
                                1, 2, 1, 2);
+    g_signal_connect (G_OBJECT (pref_dialog->port_entry), "focus_out_event",
+    		      G_CALLBACK (set_port_cb), pref_dialog);
                                
-    button = gtk_button_new_with_mnemonic (_("Set _Port"));
+    button = gtk_button_new_with_mnemonic (_("Def_ault"));
     gtk_table_attach_defaults (pref_dialog->table, button, 2, 3, 1, 2);
     g_signal_connect (G_OBJECT (button), "clicked",
-    		      G_CALLBACK (port_button_cb), pref_dialog);
+    		      G_CALLBACK (set_default_port), pref_dialog);
     
     if( gail_loaded )
     {
-        add_atk_namedesc(GTK_WIDGET(button), NULL, _("Set the port number"));
+        add_atk_namedesc(GTK_WIDGET(button), NULL, _("Reset port to default"));
         add_atk_namedesc(server_label, _("Server"), _("Server"));
         add_atk_namedesc( GTK_WIDGET (pref_dialog->server_entry), _("Server Entry"), _("Enter the Server Name"));
         add_atk_relation(server_label, GTK_WIDGET (pref_dialog->server_entry), ATK_RELATION_LABEL_FOR);
@@ -617,8 +627,8 @@ response_cb (GtkDialog *dialog, gint response)
     
 }
 
-static void
-server_button_cb (GtkButton *button, gpointer data)
+static gboolean
+set_server_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
     GDictPrefDialog *pref_dialog = data;
     gchar *server;
@@ -642,11 +652,13 @@ server_button_cb (GtkButton *button, gpointer data)
    
     if (server)
     	g_free (server);
+    	
+    return FALSE;
 }
 
 
-static void 
-port_button_cb (GtkButton *button, gpointer data)
+static gboolean 
+set_port_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
     GDictPrefDialog *pref_dialog = data;
     gchar *port;
@@ -670,8 +682,33 @@ port_button_cb (GtkButton *button, gpointer data)
     
     if (port)
     	g_free (port);
+
+    return FALSE;
 }
 
+static void
+set_default_server (GtkButton *button, gpointer data)
+{
+    GDictPrefDialog *pref_dialog = data;
+    
+    gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry), DICT_DEFAULT_SERVER);
+    set_server_cb (GTK_WIDGET (pref_dialog->port_entry), NULL, data);
+    
+}
+
+static void
+set_default_port (GtkButton *button, gpointer data)
+{
+    GDictPrefDialog *pref_dialog = data;
+    gchar *port;
+    
+    port = g_strdup_printf ("%d", DICT_DEFAULT_PORT);
+    gtk_entry_set_text (GTK_ENTRY (pref_dialog->port_entry), port);
+    g_free (port);
+    set_port_cb (GTK_WIDGET (pref_dialog->port_entry), NULL, data);
+    
+}    
+
 static void 
 smart_lookup_cb	(GtkToggleButton *toggle, gpointer data)
 {
